@@ -117,6 +117,7 @@ class ChunkedArray(awkward.array.base.AwkwardArray):
         until = min(until, len(self._chunks))
         for i in range(len(self._chunksizes), until):
             self._chunksizes.append(len(self._chunks[i]))
+            self._offsets = None
 
     def knowtype(self, at):
         if not 0 <= at < len(self._chunks):
@@ -725,6 +726,7 @@ class ChunkedArray(awkward.array.base.AwkwardArray):
             self.knowchunksizes(chunkid + 1)
             if self._chunksizes[chunkid] > 0:
                 return self._util_columns_descend(self._chunks[chunkid], seen)
+        return []
 
     def _util_rowname(self, seen):
         if id(self) in seen:
